@@ -1,35 +1,40 @@
 #' Multivariate Imputation by Chained Equations (Iteration Step)
 #'
-#' Takes a \code{mids} object, and produces a new object of class \code{mids}.
+#' Takes a \code{mids} object, performs \code{maxit} iterations and
+#' produces a new object of class \code{"mids"}.
 #'
+#' @details
 #' This function enables the user to split up the computations of the Gibbs
 #' sampler into smaller parts. This is useful for the following reasons:
-#' \itemize{ \item RAM memory may become easily exhausted if the number of
-#' iterations is large. Returning to prompt/session level may alleviate these
-#' problems.  \item The user can compute customized convergence statistics at
-#' specific points, e.g. after each iteration, for monitoring convergence.  -
-#' For computing a 'few extra iterations'.  } Note: The imputation model itself
-#' is specified in the \code{mice()} function and cannot be changed with
-#' \code{mice.mids}.  The state of the random generator is saved with the
-#' \code{mids} object.
+#'
+#' \itemize{
+#'    \item To add a few extra iteration to an existing solution.
+#'    \item If RAM memory is exhausted. Returning to prompt/session
+#'    level may alleviate such problems.
+#'    \item To customize convergence statistics at specific points, e.g.,
+#'    after every \code{maxit} iterations to monitor convergence.
+#' }
+#'
+#' The imputation model itself is specified in the \code{\link{mice}()} function
+#' and cannot be changed in \code{mice.mids()}. The state of the random
+#' generator is saved with the \code{mids} object. This ensures that the
+#' imputations are reproducible.
 #'
 #' @param obj An object of class \code{mids}, typically produces by a previous
 #' call to \code{mice()} or \code{mice.mids()}
 #' @param newdata An optional \code{data.frame} for which multiple imputations
 #' are generated according to the model in \code{obj}.
-#' @param maxit The number of additional Gibbs sampling iterations.
+#' @param maxit The number of additional Gibbs sampling iterations. The
+#' default is 1.
 #' @param printFlag A Boolean flag. If \code{TRUE}, diagnostic information
 #' during the Gibbs sampling iterations will be written to the command window.
 #' The default is \code{TRUE}.
-#' @param ... Named arguments that are passed down to the univariate imputation
+#' @param \dots Named arguments that are passed down to the univariate imputation
 #' functions.
-#' @author Stef van Buuren, Karin Groothuis-Oudshoorn, 2000
+#' @return \code{mice.mids} returns an object of class \code{"mids"}.
 #' @seealso \code{\link{complete}}, \code{\link{mice}}, \code{\link{set.seed}},
-#' \code{\link[=mids-class]{mids}}
-#' @references Van Buuren, S., Groothuis-Oudshoorn, K. (2011). \code{mice}:
-#' Multivariate Imputation by Chained Equations in \code{R}. \emph{Journal of
-#' Statistical Software}, \bold{45}(3), 1-67.
-#' \url{https://www.jstatsoft.org/v45/i03/}
+#' \code{\link{mids}}
+#' @aliases mice.mids
 #' @keywords iteration
 #' @examples
 #' imp1 <- mice(nhanes, maxit = 1, seed = 123)
@@ -47,6 +52,9 @@ mice.mids <- function(obj, newdata = NULL, maxit = 1, printFlag = TRUE, ...) {
     stop("Object should be of type mids.")
   }
 
+  # Set seed to last seed after previous imputation
+  assign(".Random.seed", obj$lastSeedValue, pos = 1)
+
   # obj contains training data, newdata contains test data
   # overwrite obj with combined obj + imp.newdata
   if (!is.null(newdata)) {
@@ -54,13 +62,15 @@ mice.mids <- function(obj, newdata = NULL, maxit = 1, printFlag = TRUE, ...) {
     if (!is.null(obj$ignore)) ignore <- obj$ignore
 
     newdata <- check.newdata(newdata, obj$data)
-    imp.newdata <- mice(newdata, m = obj$m, maxit = 0,
-                        remove.collinear = FALSE,
-                        remove.constant = FALSE)
+    imp.newdata <- mice(newdata,
+      m = obj$m, maxit = 0,
+      remove.collinear = FALSE,
+      remove.constant = FALSE
+    )
     obj <- withCallingHandlers(
       rbind.mids(obj, imp.newdata),
       warning = function(w) {
-        if(grepl("iterations differ", w$message)){
+        if (grepl("iterations differ", w$message)) {
           # Catch warnings concerning iterations, these differ by design
           invokeRestart("muffleWarning")
         }
@@ -95,8 +105,6 @@ mice.mids <- function(obj, newdata = NULL, maxit = 1, printFlag = TRUE, ...) {
   blocks <- obj$blocks
   if (is.null(blocks)) blocks <- make.blocks(obj$data)
 
-  assign(".Random.seed", obj$lastSeedValue, pos = 1)
-
   ## OK. Iterate.
   sumIt <- obj$iteration + maxit
   from <- obj$iteration + 1
@@ -144,26 +152,29 @@ mice.mids <- function(obj, newdata = NULL, maxit = 1, printFlag = TRUE, ...) {
   }
 
   ## save, and return
-  midsobj <- list(
-    data = obj$data, imp = imp, m = obj$m,
-    where = where, blocks = obj$blocks,
-    call = call, nmis = obj$nmis,
+  midsobj <- mids(
+    data = obj$data,
+    imp = imp,
+    m = obj$m,
+    where = where,
+    blocks = obj$blocks,
+    call = call,
+    nmis = obj$nmis,
     method = obj$method,
     predictorMatrix = obj$predictorMatrix,
     visitSequence = obj$visitSequence,
-    formulas = obj$formulas, post = obj$post,
+    formulas = obj$formulas,
+    post = obj$post,
     blots = obj$blots,
     ignore = obj$ignore,
     seed = obj$seed,
     iteration = sumIt,
-    lastSeedValue = .Random.seed,
+    lastSeedValue = get(".Random.seed",
+      envir = globalenv(), mode = "integer",
+      inherits = FALSE),
     chainMean = chainMean,
     chainVar = chainVar,
-    loggedEvents = loggedEvents,
-    version = packageVersion("mice"),
-    date = Sys.Date()
-  )
-  oldClass(midsobj) <- "mids"
+    loggedEvents = loggedEvents)
 
   if (!is.null(newdata)) {
     include <- c(
@@ -173,5 +184,5 @@ mice.mids <- function(obj, newdata = NULL, maxit = 1, printFlag = TRUE, ...) {
     midsobj <- filter(midsobj, include)
   }
 
-  midsobj
+  return(midsobj)
 }
